## Installation

Via [npm](https://docs.npmjs.com/):

```bash
npm install $PACKAGE$
```

Via [Yarn](https://yarnpkg.com/):

```bash
yarn add $PACKAGE$
```

Via [pnpm](https://pnpm.io/):

```bash
pnpm add $PACKAGE$
```
